<?xml version="1.0" encoding="shift_jis"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" > 
<xsl:import href="./common.xsl"/>
<xsl:output method="html" doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN" />

<!-- ****** TOP ****** -->

<xsl:template match="/">
	<xsl:apply-templates select="dynamic_document">
		<xsl:with-param name="select_type" select="'2'"/>
		<xsl:with-param name="data_type" select="$TARGET_DAT_DC"/>
		<xsl:with-param name="id" select="$HEADER_ID"/>
	</xsl:apply-templates>
</xsl:template>

<!-- ****** HEADER ****** -->

<xsl:template match="header">
	<xsl:call-template name="title_tab">
		<xsl:with-param name="name" select="concat($DC,$DETAIL)" />
		<xsl:with-param name="image" select="$IMG_DC"/>
	</xsl:call-template>

<xsl:element name="table">
	<xsl:attribute name="class">main</xsl:attribute>
	<xsl:attribute name="summary"><xsl:value-of select="$DC" /><xsl:value-of select="$DETAIL" /></xsl:attribute>

	<xsl:element name="tr">
		<xsl:attribute name="style">width:100%</xsl:attribute>
		<xsl:element name="th">
			<xsl:attribute name="style">width:150px;</xsl:attribute><xsl:value-of select="$LOGICAL_NAME" />
		</xsl:element>
		<xsl:element name="td"><xsl:value-of select="logical_name" /></xsl:element>
	</xsl:element>

	<xsl:element name="tr">
		<xsl:element name="th"><xsl:value-of select="$PHYSICAL_NAME" /></xsl:element>
		<xsl:element name="td"><xsl:value-of select="physical_name" /></xsl:element>
	</xsl:element>
	<xsl:element name="tr">
		<xsl:element name="th"><xsl:value-of select="$COMMENT" /></xsl:element>
		<xsl:element name="td"><xsl:value-of select="memo" /></xsl:element>
	</xsl:element>
	<xsl:element name="tr">
		<xsl:element name="th"><xsl:value-of select="$BASE_CLASS" /></xsl:element>
		<xsl:element name="td">
			<xsl:apply-templates select="base_class" />
		</xsl:element>
	</xsl:element>
	<xsl:element name="tr">
		<xsl:element name="th"><xsl:value-of select="$TABLE" /></xsl:element>
		<xsl:element name="td">
			<xsl:element name="a">
				<xsl:attribute name="href">
					<xsl:call-template name="create_link">
						<xsl:with-param name="data_type" select="$TARGET_DAT_TABLE"/>
						<xsl:with-param name="select_type" select="2"/>
						<xsl:with-param name="id" select="table/id"/>
					</xsl:call-template>
				</xsl:attribute>
				<xsl:value-of select="table/logical_name" /><xsl:element name="br" /><xsl:value-of select="table/physical_name"/>
			</xsl:element>
		</xsl:element>
	</xsl:element>
	<xsl:element name="tr">
		<xsl:element name="th"><xsl:value-of select="$CREATE_USER" /> (<xsl:value-of select="$CREATE_DATE" />)</xsl:element>
		<xsl:element name="td"><xsl:value-of select="create_user" /> ( <xsl:call-template name="formatdate"><xsl:with-param name="word" select="create_date"/></xsl:call-template> )</xsl:element>
	</xsl:element>
	<xsl:element name="tr">
		<xsl:element name="th"><xsl:value-of select="$UPDATE_USER" /> (<xsl:value-of select="$UPDATE_DATE" />)</xsl:element>
		<xsl:element name="td"><xsl:value-of select="update_user" /> ( <xsl:call-template name="formatdate"><xsl:with-param name="word" select="update_date"/></xsl:call-template> )</xsl:element>
	</xsl:element>
</xsl:element>
</xsl:template>

<!-- ****** DETAIL ****** -->

<xsl:template match="detail">
	<!-- RECORD -->
	<xsl:if test="$HREF = 'io'">
		<xsl:call-template name="write_data_record"/>
	</xsl:if>
	<!-- SQL -->
	<xsl:if test="$HREF = 'sql'">
		<xsl:call-template name="sql" />
	</xsl:if>
	<!-- SSUB -->
	<xsl:if test="$HREF = 'samc'">
		<xsl:call-template name="ssubs" />
	</xsl:if>
	<!-- CLIENT -->
	<xsl:if test="$HREF = 'client'">
		<xsl:call-template name="frames" />
	</xsl:if>
	<!-- BSUB -->
	<xsl:if test="$HREF = 'smc'">
		<xsl:call-template name="smcs" />
	</xsl:if>
</xsl:template>


<!-- ************************************************** -->

<xsl:template name="sql">
<xsl:choose>
	<xsl:when test="/dynamic_document/data/header/sql_type='`'">
		<xsl:element name="p"><xsl:value-of select="$DEFINITION" /></xsl:element>

		<xsl:element name="div">
			<xsl:attribute name="class">sql</xsl:attribute>
			<xsl:choose>
				<xsl:when test="/dynamic_document/data/header/base_class/search_string='SELECT'">
					<xsl:call-template name="sql_select"/>
				</xsl:when>
				<xsl:when test="/dynamic_document/data/header/base_class/search_string='INSERT'">
					<xsl:call-template name="sql_insert"/>
				</xsl:when>
				<xsl:when test="/dynamic_document/data/header/base_class/search_string='UPDATE'">
					<xsl:call-template name="sql_update"/>
				</xsl:when>
				<xsl:when test="/dynamic_document/data/header/base_class/search_string='DELETE'">
					<xsl:call-template name="sql_delete"/>
				</xsl:when>
			</xsl:choose>
		</xsl:element>
	</xsl:when>

	<xsl:otherwise>
		<xsl:element name="p"><xsl:value-of select="$FREE" /></xsl:element>
		<xsl:element name="div">
			<xsl:attribute name="class">sql</xsl:attribute>
			<xsl:for-each select="free/record/free_sql">
				<xsl:apply-templates />
			</xsl:for-each>
		</xsl:element>
	</xsl:otherwise>
</xsl:choose>
</xsl:template>

<!-- ************************************************** -->
<!--                       SELECT                       -->
<!-- ************************************************** -->

<xsl:template name="sql_select">
SELECT 
<xsl:apply-templates select="select" />
<xsl:element name="br" />FROM 
<xsl:call-template name="from"/>
<xsl:apply-templates select="where" />
<xsl:apply-templates select="order" />
</xsl:template>

<!-- ************************************************** -->
<!--                       UPDATE                       -->
<!-- ************************************************** -->

<xsl:template name="sql_update">
UPDATE <xsl:call-template name="from"/>
<xsl:element name="br" />SET <xsl:call-template name="set" />
<xsl:apply-templates select="where" />
</xsl:template>

<!-- ************************************************** -->
<!--                       INSERT                       -->
<!-- ************************************************** -->

<xsl:template name="sql_insert">
INSERT INTO 
<xsl:call-template name="from"/> (
<xsl:apply-templates select="select" />
)<xsl:element name="br" />VALUES (
	<xsl:for-each select="select/record">
		<xsl:element name="br" />
		<xsl:variable name="index"><xsl:value-of select="position()"/></xsl:variable>
		<xsl:if test="$index != '1'">,</xsl:if>
		<xsl:choose>
			<xsl:when test="condition='Œl'">
				'<xsl:value-of select="value"/>'
			</xsl:when>
			<xsl:when test="condition='vZ'">
				<xsl:value-of select="value"/>
			</xsl:when>
			<xsl:otherwise>?</xsl:otherwise>
		</xsl:choose>
	</xsl:for-each>

)
</xsl:template>

<!-- ************************************************** -->
<!--                       DELETE                       -->
<!-- ************************************************** -->

<xsl:template name="sql_delete">
DELETE FROM 
<xsl:call-template name="from"/>
<xsl:apply-templates select="where" />
</xsl:template>

<!-- ************************************************** -->
<!-- SELECT吶                                        -->
<!-- ************************************************** -->

<xsl:template match="select">
	<xsl:for-each select="record">
		<xsl:variable name="index"><xsl:value-of select="position()"/></xsl:variable>
		<xsl:if test="$index != '1'">,</xsl:if>
		<xsl:element name="a">
				<xsl:attribute name="href">
					<xsl:call-template name="create_link">
						<xsl:with-param name="data_type" select="$TARGET_DAT_DATA"/>
						<xsl:with-param name="select_type" select="3"/>
						<xsl:with-param name="id" select="./id"/>
					</xsl:call-template>
				</xsl:attribute>
			<xsl:element name="br" /><xsl:value-of select="physical_name"/>
		</xsl:element>
	</xsl:for-each>
</xsl:template>

<!-- ************************************************** -->
<!-- SET吶                                        -->
<!-- ************************************************** -->

<xsl:template name="set">
	<xsl:for-each select="select/record">
		<xsl:element name="a">
			<xsl:attribute name="href">
				<xsl:call-template name="create_link">
					<xsl:with-param name="data_type" select="$TARGET_DAT_DATA"/>
					<xsl:with-param name="select_type" select="3"/>
					<xsl:with-param name="id" select="./id"/>
				</xsl:call-template>
			</xsl:attribute>
			<xsl:element name="br" /><xsl:value-of select="physical_name"/>
		</xsl:element>
		 = 
		<xsl:choose>
			<xsl:when test="condition='Œl'">
				'<xsl:value-of select="value"/>'
			</xsl:when>
			<xsl:when test="condition='vZ'">
				<xsl:value-of select="value"/>
			</xsl:when>
			<xsl:otherwise>?</xsl:otherwise>
		</xsl:choose>
	</xsl:for-each>
</xsl:template>

<!-- ************************************************** -->
<!-- FROM吶                                        -->
<!-- ************************************************** -->

<xsl:template name="from">
<xsl:value-of select="/dynamic_document/data/header/table/physical_name"/>
</xsl:template>

<!-- ************************************************** -->
<!-- WHERE吶                                        -->
<!-- ************************************************** -->

<xsl:template match="where">
	<xsl:if test="count(record) != 0">
	<xsl:element name="br" />WHERE <xsl:element name="br" />
	</xsl:if>
	
	<xsl:for-each select="record">
		<xsl:variable name="index"><xsl:value-of select="position()"/></xsl:variable>
		<xsl:if test="$index != '1'"><xsl:element name="br" /><xsl:value-of select="conjunction" /><xsl:text> </xsl:text></xsl:if>
		<xsl:value-of select="before_bracket"/>
		<xsl:element name="a">
			<xsl:attribute name="href">
				<xsl:call-template name="create_link">
					<xsl:with-param name="data_type" select="$TARGET_DAT_DATA"/>
					<xsl:with-param name="select_type" select="3"/>
					<xsl:with-param name="id" select="./id"/>
				</xsl:call-template>
			</xsl:attribute>
			<xsl:value-of select="physical_name"/>
		</xsl:element>
		<xsl:text> </xsl:text><xsl:value-of select="compare"/>
		<xsl:choose>
			<xsl:when test="condition='Œl'">
				'<xsl:value-of select="value"/>'
			</xsl:when>
			<xsl:when test="condition='vZ'">
				<xsl:value-of select="value"/>
			</xsl:when>
			<xsl:otherwise> ?</xsl:otherwise>
		</xsl:choose>
		<xsl:value-of select="after_bracket"/>
	</xsl:for-each>
</xsl:template>

<!-- ************************************************** -->
<!-- ORDER吶                                        -->
<!-- ************************************************** -->

<xsl:template match="order">
	<xsl:if test="count(record) != 0">
	<xsl:element name="br" />ORDER BY  
	</xsl:if>

	<xsl:for-each select="record">
		<xsl:variable name="index"><xsl:value-of select="position()"/></xsl:variable>
		<xsl:if test="$index != '1'">,</xsl:if>
		<xsl:element name="a">
			<xsl:attribute name="href">
				<xsl:call-template name="create_link">
					<xsl:with-param name="data_type" select="$TARGET_DAT_DATA"/>
					<xsl:with-param name="select_type" select="3"/>
					<xsl:with-param name="id" select="./id"/>
				</xsl:call-template>
			</xsl:attribute>
			<xsl:value-of select="physical_name"/>
		</xsl:element>
		<xsl:choose>
			<xsl:when test="order_value='Descending'"> DESC</xsl:when>
			<xsl:otherwise> ASC</xsl:otherwise>
		</xsl:choose>

	</xsl:for-each>
</xsl:template>

<!-- ************************************************** -->
<!-- TEXTm[h[`]<xsl:element name="br" />ɕϊ   -->
<!-- ************************************************** -->

<xsl:template match="text()" name="eLXg">
	<xsl:param name="eLXg" select="."/>
	<xsl:value-of select="substring-before($eLXg,'`')"/>
	<xsl:choose>
		<xsl:when test="contains($eLXg,'`')">
			<xsl:element name="br" />
			<xsl:call-template name="eLXg">
				<xsl:with-param name="eLXg" select="substring-after($eLXg,'`')"/>
			</xsl:call-template>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="$eLXg"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- ************ /<xsl:value-of select="$OUT_REC" />@o Tu[` common.xsl㏑ ************** -->

<xsl:template name="write_data_record_sub">
	<xsl:param name="name"/>

	<xsl:element name="table">
		<xsl:attribute name="class">main</xsl:attribute>
		<xsl:attribute name="summary">record</xsl:attribute>

		<xsl:element name="tr">
			<xsl:element name="th"></xsl:element>
			<xsl:element name="th"><xsl:value-of select="$LOGICAL_NAME" /></xsl:element>
			<xsl:element name="th"><xsl:value-of select="$PHYSICAL_NAME" /></xsl:element>
		</xsl:element>
		<xsl:for-each select="record">
			<xsl:element name="tr">
				<xsl:element name="td"><xsl:number level="single" format="1" count="record" /></xsl:element>
				<xsl:element name="td">
					<xsl:element name="a">
						<xsl:attribute name="href">
							<xsl:call-template name="create_link">
								<xsl:with-param name="data_type" select="$TARGET_DAT_DATA"/>
								<xsl:with-param name="select_type" select="3"/>
								<xsl:with-param name="id" select="./id"/>
							</xsl:call-template>
						</xsl:attribute>
						<xsl:value-of select="logical_name" />
					</xsl:element>
				</xsl:element>
				<xsl:element name="td"><xsl:value-of select="physical_name" /></xsl:element>
			</xsl:element>
		</xsl:for-each>
		
	</xsl:element>
</xsl:template>

</xsl:stylesheet>
