<?xml version="1.0" encoding="shift_jis"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" > 
<xsl:import href="./common.xsl"/>
<xsl:output method="html" doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN" />

<!-- ****** TOP ****** -->

<xsl:template match="/">
	<xsl:apply-templates select="dynamic_document">
		<xsl:with-param name="select_type" select="'2'"/>
		<xsl:with-param name="data_type" select="$TARGET_CS_EXECUTION"/>
		<xsl:with-param name="id" select="$HEADER_ID"/>
	</xsl:apply-templates>
</xsl:template>

<!-- ****** HEADER ****** -->

<xsl:template match="header">
	<xsl:call-template name="sub_links"/>
	<xsl:call-template name="frame_info"/>

	<xsl:call-template name="title_tab">
		<xsl:with-param name="name" select="concat($EXECUTION,$DETAIL)" />
		<xsl:with-param name="image" select="$IMG_EXECUTION"/>
	</xsl:call-template>

<xsl:element name="table">
	<xsl:attribute name="class">main</xsl:attribute>
	<xsl:attribute name="summary"><xsl:value-of select="$EXECUTION" /><xsl:value-of select="$DETAIL" /></xsl:attribute>

	<xsl:element name="tr">
		<xsl:attribute name="style">width:100%</xsl:attribute>
		<xsl:element name="th">
			<xsl:attribute name="style">width:150px;</xsl:attribute><xsl:value-of select="$LOGICAL_NAME" />
		</xsl:element>
		<xsl:element name="td"><xsl:value-of select="logical_name" /></xsl:element>
	</xsl:element>

	<xsl:element name="tr">
		<xsl:element name="th"><xsl:value-of select="$PHYSICAL_NAME" /></xsl:element>
		<xsl:element name="td"><xsl:value-of select="physical_name" /></xsl:element>
	</xsl:element>
	<xsl:element name="tr">
		<xsl:element name="th"><xsl:value-of select="$COMMENT" /></xsl:element>
		<xsl:element name="td"><xsl:value-of select="memo" /></xsl:element>
	</xsl:element>

</xsl:element>

</xsl:template>
<!-- ****** DETAIL ****** -->
<xsl:template match="detail">

	<!-- TIMING -->

	<xsl:if test="$HREF = 'timing'">
		<xsl:call-template name="executions"/>
	</xsl:if>

</xsl:template>

<xsl:template name="executions">
	<xsl:element name="br" />
	<xsl:element name="table">
		<xsl:attribute name="class">main</xsl:attribute>
		<xsl:attribute name="summary">execution</xsl:attribute>

		<xsl:element name="tr">
			<xsl:attribute name="style">width:100%</xsl:attribute>
			<xsl:element name="th"></xsl:element>
			<xsl:element name="th">
				<xsl:attribute name="colspan">3</xsl:attribute><xsl:value-of select="$OBJECT" />
			</xsl:element>
			<xsl:element name="th"><xsl:value-of select="$HTML" /></xsl:element>
			<xsl:element name="th"><xsl:value-of select="$ERROR_HTML" /></xsl:element>
			<xsl:element name="th"><xsl:value-of select="$USER_ERROR" /></xsl:element>
			<xsl:element name="th"><xsl:value-of select="$COMMENT" /></xsl:element>
		</xsl:element>

		<xsl:for-each select="record">
			<xsl:element name="tr">
				<xsl:element name="td">
					<xsl:attribute name="style">text-align:right</xsl:attribute><xsl:number level="single" format="1" count="record" />
				</xsl:element>
			
				<xsl:element name="td">
					<xsl:attribute name="style">text-align:center</xsl:attribute>
					<xsl:choose>
						<xsl:when test="enable[.='1']"></xsl:when>
						<xsl:when test="enable[.='0']">~</xsl:when>
						<xsl:otherwise></xsl:otherwise>
					</xsl:choose>
				</xsl:element>

				<xsl:choose>
			    	<xsl:when test="tran/id[.!='']">
						<xsl:element name="td">
							<xsl:attribute name="style">width:25;</xsl:attribute><xsl:call-template name="image_of_tran"/>
						</xsl:element>
						<xsl:element name="td">
							<xsl:element name="a">
								<xsl:attribute name="href">
									<xsl:call-template name="create_link">
										<xsl:with-param name="data_type" select="$TARGET_CS_HTRAN"/>
										<xsl:with-param name="select_type" select="2"/>
										<xsl:with-param name="id" select="tran/id"/>
									</xsl:call-template>
								</xsl:attribute>
								<xsl:value-of select="tran/logical_name" /><xsl:element name="br" /><xsl:value-of select="tran/physical_name" />
							</xsl:element>
						</xsl:element>
					</xsl:when>

					<xsl:when test="rule/id[.!='']">
						<xsl:element name="td">
							<xsl:attribute name="style">width:25;</xsl:attribute><xsl:call-template name="image_of_rule"/>
						</xsl:element>
						<xsl:element name="td">
							<xsl:element name="a">
								<xsl:attribute name="href">
									<xsl:call-template name="create_link">
										<xsl:with-param name="data_type" select="$TARGET_CS_HRULE"/>
										<xsl:with-param name="select_type" select="2"/>
										<xsl:with-param name="id" select="rule/id"/>
									</xsl:call-template>
								</xsl:attribute>
								<xsl:value-of select="rule/logical_name" /><xsl:element name="br" /><xsl:value-of select="rule/physical_name" />
							</xsl:element>
						</xsl:element>
					</xsl:when>
					
					<xsl:otherwise>
						<xsl:element name="td">
							<xsl:attribute name="style">width:25;</xsl:attribute><xsl:call-template name="image_of_html"/>
						</xsl:element>
						<xsl:element name="td">
						</xsl:element>
					</xsl:otherwise>
				</xsl:choose>
				
				<xsl:element name="td">
					<xsl:if test="html/id[.!='']">
						<xsl:element name="a">
							<xsl:attribute name="href">
								<xsl:call-template name="create_link">
									<xsl:with-param name="data_type" select="$TARGET_HTML"/>
									<xsl:with-param name="select_type" select="2"/>
									<xsl:with-param name="id" select="html/id"/>
								</xsl:call-template>
							</xsl:attribute>
							<xsl:value-of select="html/logical_name" /><xsl:element name="br" /><xsl:value-of select="html/physical_name" />
						</xsl:element>
					</xsl:if>
				</xsl:element>
				<xsl:element name="td">
					<xsl:if test="html_error/id[.!='']">
						<xsl:element name="a">
							<xsl:attribute name="href">
								<xsl:call-template name="create_link">
									<xsl:with-param name="data_type" select="$TARGET_HTML"/>
									<xsl:with-param name="select_type" select="2"/>
									<xsl:with-param name="id" select="html_error/id"/>
								</xsl:call-template>
							</xsl:attribute>
							<xsl:value-of select="html_error/logical_name" /><xsl:element name="br" /><xsl:value-of select="html_error/physical_name" />
						</xsl:element>
					</xsl:if>
				</xsl:element>
				<xsl:element name="td"><xsl:value-of select="user_error" /></xsl:element>
				<xsl:element name="td"><xsl:value-of select="memo" /></xsl:element>
			</xsl:element>
		</xsl:for-each>
	</xsl:element>
</xsl:template>

</xsl:stylesheet>
